//
// This file "SalDef.h" contains the structure definitions used by SalatTimes
// Revision 2.5
// It is not recommended to modify this file. Please do not manipulate the definition for unused parameters
// to avoid any corruption in data structures.
//
#ifndef SALDEF
#define SALDEF_H
#endif

#define MaxNameLength 41
#define MaxPathLength 80
#define FAlse 0
#define TRue 1

typedef struct {
    int year;			  // Julian/Gregorian year. Valid range -2000 to 6000
	int iyear;			  // Islamic year. Valid range 1 to 6000
    unsigned char month;  // Julian/Gregorian month. Valid range 1 to 12
    unsigned char imonth; // Islamic month. Valid range 1 to 12
    double day;			  // Julian/Gregorian day. Valid range 1 to 7
	double iday;		  // Islamic day. Valid range 1 to 7
	int isValid;		  // The date structure represents Islamic date (1) or Julian/Gregorian (0)
    unsigned char hour;   // Not used
    unsigned char minute; // Not used
    unsigned char second; // Not used
} Date;

typedef struct {
    char name[MaxNameLength]; // The name of location
    double lat;				  // The value of latitude in Radian
    double lon;				  // The value of longitude in Radian
    int height;				  // The height of location in meters. Valid range -999 to 9999
    float zone;				  // The value of timezone. Minus is West of Greewitch
    int saveStr;			  // DST start date. bit 0 to 7 is the day and bit 8 to 12 is the month.
                              // The days are coded as follows:
                              // 1-31 fixed days of the month
                              // 32 = First Monday, 33 = 2nd Monday, 34 = 3rd Monday, 35 = 4th Monday, 36 = Last Monday
                              // Continue with the rest of days of the week until 66 = Last Sunday
							  // Zero if DST is not used
    int saveEnd;              // DST end date. bit 0 to 7 is the day and bit 8 to 12 is the month. see above
							  // Zero if DST is not used
} Location;

typedef struct {
    float imsakAngle;				// Imsak angle in degrees. Valid range -20 to -1
    float fajrAngle;				// Fajr angle in degrees. Valid range from the value of Imsak/Isha to -1
    float ishaAngle;				// Isha angle in degrees. Valid range -20 to -1
	int fiqh;						// The fiq to be applied.
									// 0 = Jafari
									// 1 = Shafi'i
									// 2 = Hanafi
									// 3 = Maliki
									// 4 = Hanbali

    int dist;						// The semidiameter of the area to calculate for. Valid range from -999 to 9999
	int precision;					// The output prayer times in seconds (0) or minutes (1)
	int addMin;						// The number of minutes to be added to Maghrib time. Valid range 0 to 30 minutes
    int temp;						// The temprature in degrees
	int pressure;					// The pressure in millibars
	int refraction;					// Not used anymore
	int secondsToCorrect;			// The number of seconds to add or subtract from prayer times to
								    // compensate for eventual errors. Valid range 0 to 600
	int maxErrorInSec;				// The limit to stop iteration when calculating moon and sun rise and set times
								    // valid range 0 to 60
    float visibleLimit;				// The limit of visibilty to determine the start of next Islamic month.
								    // If the sum of elongation and relative altitude is lower than this
								    // then next day is a possible start day.
								    // Valid range 0 to 30 degrees.
	int rule;						// The rule to be used at high latitudes
								    // 0 = non
								    // 1 = 1/7 of day when needed
								    // 2 = 1/7 of day always
								    // 3 = 1/7 of night when needed
								    // 4 = 1/7 of night always
								    // 5 = Nearest location-all prayers
								    // 6 = Nearest location-needed prayers
								    // 7 = Nearest day-all prayers
								    // 8 = Nearest day-needed prayers
								    // 9 = n minutes for Fajr&Isha prayers
	int programFlags;			    // Only bit 8-10 are used to indicate the type of calculation
									// Bit 8-10 = 0 Calculate for a day
									// Bit 8-10 = 1 Calculate for a month
									// Bit 8-10 = 2 Calculate for a year
	int adjust;						// The number of days to shift Islamic date in relatin to Julian/Gregorian. Valid range -3 to 3
	int nMinutes;					// The number of minutes for rule number 9 at high latitudes (n minutes for Fajr&Isha prayers)
								    // Valid range 1 to 120 minutes
	int timer;				        // Not used
	int bMin;				        // Not used
	char editor[MaxPathLength];     // Not used
	char soundFile[MaxPathLength];  // Not used
	char soundFile2[MaxPathLength]; // Not used
} ConfigData;
