
#include <fstream.h>
#include <stdio.h>
#include <string.h>
#include "SalDef.h"


extern "C" int __stdcall SalisValidDate(Date *date, int type);
// Use this function to test if a date (Islamic or Julian/Gregorian is a valid date
// 'type' indicates the type of date. 0 = Julian/Gregorian and 1 = Islamic

extern "C" void __stdcall SalAdToIslamic(Date *date,Location *loc, ConfigData *data);
extern "C" void __stdcall SalIslamicToAd(Date *date,Location *loc, ConfigData *data);
// The 2 functions above convert between Islamic and Julian/Gregorian calenders.
// The result is stored in the date structure

extern "C" void __stdcall SalQiblaInfo(Location *loc, Date *date, double *dir, double *dist, double *magDec);
// Output arguments are 'dir' which is the direction in degrees.
// 'dist' is the distance between Mecca and the place in question in Kilometers.
// 'magDec' is the Magnetic Declination for the place in question in degrees.

extern "C" void __stdcall SalCalculate(Date *date,Location *loc,ConfigData *data,char *s);
extern "C" void __stdcall SalMoonInfo(Date *date, Location *loc, ConfigData *data,char *s);
// The 2 functions above return the result in a character string. Make sure the string is long enough.
// You can format the output string in the way you prefer

int main()
{
  Location loc;
  ConfigData data;
  Date date;
  double magDec;
  char output[3000];			// Make sure the length is enough. I.e. for year 
								// calculation you need more!
  ofstream outFile;
  double dir, dist;

  data.imsakAngle=(float)-16.0; // 16 degrees and 0 minutes
  data.fajrAngle=(float)-13.5;  // 13 degrees and 30 minutes
  data.ishaAngle=(float)-16.0;  // 16 degrees and 0 minutes
  data.dist=10;					// distance = 10 kilometers
  data.fiqh=0;					// Fiqh = Jafari
  data.precision=1;				// precision = minutes
  data.addMin=0;				// Zero minutes to be added to Maghrib time
  data.secondsToCorrect=2;		// It is recommended to keep this value
  data.maxErrorInSec=1;			// It is recommended to keep this value
  data.rule=1;					// Rule = 1/7 of day when needed
  data.temp=10;					// Change the value of temperature only if needed
  data.pressure=0;			    // The prgram will estimate correct value for pressure
  data.visibleLimit=(float)15;  // visible limit = 15 degrees and 0 minutes
  data.adjust=0;				// Do not adjust Islamic date in relation to Julian/Gregorian
  data.nMinutes=90;				// It is recommended to keep this value
  data.programFlags=0X100;		// 0X000 for day, 0X100 for month and 0X200 for year calculation
  strcpy(loc.name,"Manama,Bahrain");
  loc.lat=26+14/60.0+10/3600.0; // Latitude = 26 degrees, 14 minutes and 50 seconds North
  loc.lon=50+34/60.0+59/3600.0; // Longitude = 50 degrees, 34 minutes and 50 seconds East 
  loc.zone=(float)3.0;			// timezone is GMT + 3 hours
  loc.saveStr=0;				// DST is not applicable
  loc.saveEnd=0;				// DST is not applicable
  loc.height=0;					// The height of location is zero
  date.day=1;					// This is just a test date
  date.month=1;
  date.year=2000;
  date.isValid=0;				// The date structure represents Gregorian date

  outFile.open("SaTest.ans");
  if (outFile)
  {
    if(SalisValidDate(&date,0)==TRue) // Test Gregorian date
	{
      SalAdToIslamic(&date, &loc, &data);
	  outFile << " The date corresponds to: " << int(date.iday) << "/" << int(date.imonth) << "/" << date.iyear << " AH" << endl;
      SalIslamicToAd(&date, &loc, &data);
	  outFile << " The date corresponds to: " << int(date.day) << "/" << int(date.month) << "/" << date.year << " AD" << endl;
	  SalCalculate(&date,&loc,&data,output);
	  outFile << endl << "				Prayer schedule" << endl;
	  outFile << output;
	  SalMoonInfo(&date,&loc,&data,output);
	  outFile << endl << "				Moon information" << endl;
	  outFile << output;
	  SalQiblaInfo(&loc,&date,&dir,&dist,&magDec);
	  outFile << endl << "				Qibla information for " << loc.name << endl;
	  outFile << " The Qibla is " << dir << " degrees from Geographic North" << endl;
	  outFile << " The Magnetic Declination is " << magDec << " degrees" << endl;
	  outFile << " The distance from " << loc.name << " to Mecca is " << dist << endl;
	  outFile.close();
	}
  }
  return 1;
}